@@ -1,10 +1,12 @@
-use Map::Metro::Standard;
+use Opendata::GTFS::Standard;
+use strict;
+use warnings;
 
-our $VERSION = '0.0100'; # VERSION:
 # PODNAME: Opendata::GTFS::Feed::Exception::FeedContainsFaultyHeader
 
 class Opendata::GTFS::Feed::Exception::FeedContainsFaultyHeader with Opendata::GTFS::Feed::Exception using Moose {
 
+    our $VERSION = '0.0101'; # VERSION:
     use Opendata::GTFS::Feed::Exception -all;
 
     has filename => (
@@ -39,7 +41,7 @@ Opendata::GTFS::Feed::Exception::FeedContainsFaultyHeader
 
 =head1 VERSION
 
-Version 0.0100, released 2015-01-31.
+Version 0.0101, released 2015-02-19.
 
 =head1 HOMEPAGE
 
