@@ -1,15 +1,16 @@
 use 5.14.0;
-
-our $VERSION = '0.0100'; # VERSION
+use strict;
+use warnings;
 
 package Opendata::GTFS::Standard {
 
+    our $VERSION = '0.0101'; # VERSION
+
     use base 'Moops';
     use List::AllUtils();
     use MooseX::StrictConstructor();
     use Types::Opendata::GTFS();
     use Safe::Isa;
-    
 
     sub import {
         my $class = shift;
@@ -40,7 +41,7 @@ Opendata::GTFS::Standard
 
 =head1 VERSION
 
-Version 0.0100, released 2015-01-31.
+Version 0.0101, released 2015-02-19.
 
 =head1 HOMEPAGE
 
