@@ -1,11 +1,14 @@
 use Opendata::GTFS::Standard;
+use strict;
+use warnings;
 
-our $VERSION = '0.0100'; # VERSION
 # PODNAME: Opendata::GTFS::Type::Trip
 # ABSTRACT: Trip
 
 class Opendata::GTFS::Type::Trip using Moose {
 
+    our $VERSION = '0.0101'; # VERSION
+
     my @columns = qw/
         1 route_id
         1 service_id
@@ -44,7 +47,7 @@ Opendata::GTFS::Type::Trip - Trip
 
 =head1 VERSION
 
-Version 0.0100, released 2015-01-31.
+Version 0.0101, released 2015-02-19.
 
 
 
