@@ -1,7 +1,8 @@
 use 5.14.0;
 use Moops;
+use strict;
+use warnings;
 
-our $VERSION = '0.0100'; # VERSION:
 # ABSTRACT: Types for Opendata::GTFS
 # PODNAME: Types::Opendata::GTFS
 
@@ -12,12 +13,15 @@ extends  Types::Standard,
          Types::URI
 
 {
+
+    our $VERSION = '0.0101'; # VERSION:
+
     class_type Agency        => { class => 'Opendata::GTFS::Type::Agency' };
-	class_type Calendar      => { class => 'Opendata::GTFS::Type::Calendar' };
-	class_type CalendarDate  => { class => 'Opendata::GTFS::Type::CalendarDate' };
-	class_type FareAttribute => { class => 'Opendata::GTFS::Type::FareAttribute' };
-	class_type FareRule      => { class => 'Opendata::GTFS::Type::FareRule' };
-	class_type Frequency     => { class => 'Opendata::GTFS::Type::Frequency' };
+    class_type Calendar      => { class => 'Opendata::GTFS::Type::Calendar' };
+    class_type CalendarDate  => { class => 'Opendata::GTFS::Type::CalendarDate' };
+    class_type FareAttribute => { class => 'Opendata::GTFS::Type::FareAttribute' };
+    class_type FareRule      => { class => 'Opendata::GTFS::Type::FareRule' };
+    class_type Frequency     => { class => 'Opendata::GTFS::Type::Frequency' };
     class_type Route         => { class => 'Opendata::GTFS::Type::Route' };
     class_type Shape         => { class => 'Opendata::GTFS::Type::Shape' };
     class_type Stop          => { class => 'Opendata::GTFS::Type::Stop' };
@@ -40,7 +44,7 @@ Types::Opendata::GTFS - Types for Opendata::GTFS
 
 =head1 VERSION
 
-Version 0.0100, released 2015-01-31.
+Version 0.0101, released 2015-02-19.
 
 =head1 TYPES
 
